memory = {}

for line in open('aaa'):
    tmp = line.split()
    if tmp != 'XXX':
        continue

    if tmp[1] == 'allocted':
        addr = tmp[2]
        size = int(tmp[3])
        assert addr not in memory
        memory[addr] = size

    elif tmp[1] == 'freeing':
        addr = tmp[2]
        assert addr in memory
        del memory[addr]
    else:
        assert False

print memory



import pickle
import time

import ahocorasick
import psutil
import requests

automaton = ahocorasick.Automaton()

r = requests.get('https://en.wikipedia.org/wiki/Aho%E2%80%93Corasick_algorithm')
assert r.ok

for word in r.text.split():
    if word.isalpha():
        automaton.add_word(word.encode('utf8').lower(), word)

automaton.make_automaton()
pickled = pickle.dumps(automaton)

print('Cycles    Free MiB')
for i in range(10000):
    if i % 1000 == 0:
        free = psutil.virtual_memory().free
        print('{:05d}     {}'.format(i, free/1000000))
    unpickled = pickle.loads(pickled)
    time.sleep(0.001)



import ahocorasick
import _pickle

A = ahocorasick.Automaton()
for i in range(0, 65):
    A.add_word(str(i), (i, i))

path = 'aho'
with open(path, 'wb') as f:
    _pickle.dump(A, f)

with open(path, 'rb') as f:
    _pickle.load(f)

